---
title: Introduction
sidebar_position: 0
---

# *package* pyromod

This is a concise list of the main modules, objects, helpers, and decorators provided by pyromod.

- Modules:
    - pyromod.config
    - pyromod.helpers
    - pyromod.listen
    - pyromod.nav
    - pyromod.utils
    - pyromod.exceptions
    - pyromod.types

- Objects:
    - pyromod.config.config
    - pyromod.listen.Client
    - pyromod.listen.Message
    - pyromod.listen.Chat
    - pyromod.listen.User
    - pyromod.nav.Pagination
    - pyromod.types.Identifier
    - pyromod.types.ListenerTypes
    - pyromod.types.Listener
    - pyromod.exceptions.ListenerTimeout
    - pyromod.exceptions.ListenerStopped
    - pyromod.utils.patch_into
    - pyromod.utils.should_patch

- Helpers:
    - pyromod.helpers.ikb
    - pyromod.helpers.bki
    - pyromod.helpers.ntb
    - pyromod.helpers.btn
    - pyromod.helpers.kb
    - pyromod.helpers.kbtn
    - pyromod.helpers.array_chunk
    - pyromod.helpers.force_reply

- Decorators:
    - pyromod.utils.patch_into(target_class)
    - pyromod.utils.should_patch(func)
